# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class CandidateCriteriaSchema(BaseModel):
    """
    Comparison criteria object for candidate evaluation. Contains expected values from the job, received values from the talent, and comparison metadata.
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="Display name of the criteria")
    description: Optional[StrictStr] = Field(default=None, description="Description of what this criteria evaluates")
    priority: Optional[StrictStr] = Field(default=None, description="Priority level of this criteria")
    priority_confidence: Optional[StrictStr] = Field(default=None, description="Confidence level of the priority assignment", alias="priorityConfidence")
    priority_reasoning: Optional[StrictStr] = Field(default=None, description="Explanation for the assigned priority level", alias="priorityReasoning")
    expected: Optional[List[Dict[str, Any]]] = None
    received: Optional[List[Dict[str, Any]]] = None
    weight: Optional[StrictStr] = Field(default=None, description="Weight factor for this criteria in overall scoring")
    rating: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Match rating for this criteria (0-5)")
    prev_rating: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Previous rating before recalculation", alias="prevRating")
    data_available: Optional[StrictBool] = Field(default=None, description="Whether data was available to perform the comparison", alias="dataAvailable")
    comparison_confidence: Optional[StrictStr] = Field(default=None, description="Confidence level of the comparison result", alias="comparisonConfidence")
    comparison_reasoning: Optional[StrictStr] = Field(default=None, description="Explanation of the comparison result", alias="comparisonReasoning")
    is_comparison_assumed: Optional[StrictBool] = Field(default=None, description="Whether the comparison was assumed rather than directly derived", alias="isComparisonAssumed")
    __properties: ClassVar[List[str]] = ["name", "description", "priority", "priorityConfidence", "priorityReasoning", "expected", "received", "weight", "rating", "prevRating", "dataAvailable", "comparisonConfidence", "comparisonReasoning", "isComparisonAssumed"]

    @field_validator('priority')
    def priority_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['low', 'medium', 'high', 'must']):
            raise ValueError("must be one of enum values ('low', 'medium', 'high', 'must')")
        return value

    @field_validator('priority_confidence')
    def priority_confidence_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['low', 'medium', 'high']):
            raise ValueError("must be one of enum values ('low', 'medium', 'high')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CandidateCriteriaSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if expected (nullable) is None
        # and model_fields_set contains the field
        if self.expected is None and "expected" in self.model_fields_set:
            _dict['expected'] = None

        # set to None if received (nullable) is None
        # and model_fields_set contains the field
        if self.received is None and "received" in self.model_fields_set:
            _dict['received'] = None

        # set to None if rating (nullable) is None
        # and model_fields_set contains the field
        if self.rating is None and "rating" in self.model_fields_set:
            _dict['rating'] = None

        # set to None if prev_rating (nullable) is None
        # and model_fields_set contains the field
        if self.prev_rating is None and "prev_rating" in self.model_fields_set:
            _dict['prevRating'] = None

        # set to None if comparison_confidence (nullable) is None
        # and model_fields_set contains the field
        if self.comparison_confidence is None and "comparison_confidence" in self.model_fields_set:
            _dict['comparisonConfidence'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CandidateCriteriaSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "priority": obj.get("priority"),
            "priorityConfidence": obj.get("priorityConfidence"),
            "priorityReasoning": obj.get("priorityReasoning"),
            "expected": obj.get("expected"),
            "received": obj.get("received"),
            "weight": obj.get("weight"),
            "rating": obj.get("rating"),
            "prevRating": obj.get("prevRating"),
            "dataAvailable": obj.get("dataAvailable"),
            "comparisonConfidence": obj.get("comparisonConfidence"),
            "comparisonReasoning": obj.get("comparisonReasoning"),
            "isComparisonAssumed": obj.get("isComparisonAssumed")
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class UserAttributesSchema(BaseModel):
    """
    UserAttributesSchema
    """ # noqa: E501
    email: StrictStr
    name: StrictStr
    gender: Optional[StrictStr] = None
    locale: Optional[StrictStr] = None
    phone: Optional[StrictStr] = None
    is_system: Optional[StrictBool] = Field(default=None, alias="isSystem")
    address: Optional[Dict[str, Any]] = None
    settings: Optional[Dict[str, Any]] = None
    connections: Optional[Dict[str, Any]] = None
    avatar_url: Optional[StrictStr] = Field(default=None, alias="avatarUrl")
    status: Optional[StrictStr] = None
    history_events: Optional[List[UserHistoryEventSchema]] = Field(default=None, alias="historyEvents")
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["email", "name", "gender", "locale", "phone", "isSystem", "address", "settings", "connections", "avatarUrl", "status", "historyEvents", "timestamps"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in history_events (list)
        _items = []
        if self.history_events:
            for _item_history_events in self.history_events:
                if _item_history_events:
                    _items.append(_item_history_events.to_dict())
            _dict['historyEvents'] = _items
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "email": obj.get("email"),
            "name": obj.get("name"),
            "gender": obj.get("gender"),
            "locale": obj.get("locale"),
            "phone": obj.get("phone"),
            "isSystem": obj.get("isSystem"),
            "address": obj.get("address"),
            "settings": obj.get("settings"),
            "connections": obj.get("connections"),
            "avatarUrl": obj.get("avatarUrl"),
            "status": obj.get("status"),
            "historyEvents": [UserHistoryEventSchema.from_dict(_item) for _item in obj["historyEvents"]] if obj.get("historyEvents") is not None else None,
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create User
        """
        pass

    def test_create_user_upload(self) -> None:
        """Test case for create_user_upload

        Create User Upload
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete User
        """
        pass

    def test_list_user_apikeys(self) -> None:
        """Test case for list_user_apikeys

        List User Apikeys
        """
        pass

    def test_list_user_apikeys_relationship(self) -> None:
        """Test case for list_user_apikeys_relationship

        List User Apikeys Relationship
        """
        pass

    def test_list_user_jobs(self) -> None:
        """Test case for list_user_jobs

        List User Jobs
        """
        pass

    def test_list_user_jobs_relationship(self) -> None:
        """Test case for list_user_jobs_relationship

        List User Jobs Relationship
        """
        pass

    def test_list_user_roles(self) -> None:
        """Test case for list_user_roles

        List User Roles
        """
        pass

    def test_list_user_roles_relationship(self) -> None:
        """Test case for list_user_roles_relationship

        List User Roles Relationship
        """
        pass

    def test_list_users(self) -> None:
        """Test case for list_users

        List Users
        """
        pass

    def test_show_user(self) -> None:
        """Test case for show_user

        Show User
        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        Update User
        """
        pass

    def test_user_apikeys_options(self) -> None:
        """Test case for user_apikeys_options

        User Apikeys Options
        """
        pass

    def test_user_apikeys_relationships_options(self) -> None:
        """Test case for user_apikeys_relationships_options

        User Apikeys Relationships Options
        """
        pass

    def test_user_jobs_options(self) -> None:
        """Test case for user_jobs_options

        User Jobs Options
        """
        pass

    def test_user_jobs_relationships_options(self) -> None:
        """Test case for user_jobs_relationships_options

        User Jobs Relationships Options
        """
        pass

    def test_user_options(self) -> None:
        """Test case for user_options

        User Options
        """
        pass

    def test_user_roles_options(self) -> None:
        """Test case for user_roles_options

        User Roles Options
        """
        pass

    def test_user_roles_relationships_options(self) -> None:
        """Test case for user_roles_relationships_options

        User Roles Relationships Options
        """
        pass

    def test_user_uploads_options(self) -> None:
        """Test case for user_uploads_options

        User Uploads Options
        """
        pass

    def test_users_options(self) -> None:
        """Test case for users_options

        Users Options
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_tenant_request_body import CreateTenantRequestBody

class TestCreateTenantRequestBody(unittest.TestCase):
    """CreateTenantRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateTenantRequestBody:
        """Test CreateTenantRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateTenantRequestBody`
        """
        model = CreateTenantRequestBody()
        if include_optional:
            return CreateTenantRequestBody(
                data = smartytalent_client.models.create_tenant_request_body_data.CreateTenantRequestBodyData(
                    type = 'tenants', 
                    attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                        name = '', 
                        username = '', 
                        email = '01234', 
                        status = '', 
                        short_code = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        phone = '', 
                        address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                            county = '', 
                            country = '', 
                            city = '', 
                            postalcode = '', 
                            street = '', ), 
                        settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                            ad = smartytalent_client.models.ad.ad(), 
                            conversation = smartytalent_client.models.conversation.conversation(), 
                            report = smartytalent_client.models.report.report(), 
                            email = smartytalent_client.models.email.email(), 
                            language = '', 
                            calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                                enabled = True, 
                                twilio_subaccount_sid = '', 
                                twilio_phone_number = '', 
                                twilio_phone_sid = '', 
                                provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        plan = '0', 
                        active_languages = [
                            'ae-IO'
                            ], 
                        trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timezone = '', 
                        logo_url = '', 
                        boe_phone = '', 
                        boe_email = '', ), 
                    relationships = smartytalent_client.models.tenant_relationships_schema.TenantRelationshipsSchema(), )
            )
        else:
            return CreateTenantRequestBody(
                data = smartytalent_client.models.create_tenant_request_body_data.CreateTenantRequestBodyData(
                    type = 'tenants', 
                    attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                        name = '', 
                        username = '', 
                        email = '01234', 
                        status = '', 
                        short_code = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        phone = '', 
                        address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                            county = '', 
                            country = '', 
                            city = '', 
                            postalcode = '', 
                            street = '', ), 
                        settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                            ad = smartytalent_client.models.ad.ad(), 
                            conversation = smartytalent_client.models.conversation.conversation(), 
                            report = smartytalent_client.models.report.report(), 
                            email = smartytalent_client.models.email.email(), 
                            language = '', 
                            calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                                enabled = True, 
                                twilio_subaccount_sid = '', 
                                twilio_phone_number = '', 
                                twilio_phone_sid = '', 
                                provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        plan = '0', 
                        active_languages = [
                            'ae-IO'
                            ], 
                        trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timezone = '', 
                        logo_url = '', 
                        boe_phone = '', 
                        boe_email = '', ), 
                    relationships = smartytalent_client.models.tenant_relationships_schema.TenantRelationshipsSchema(), ),
        )
        """

    def testCreateTenantRequestBody(self):
        """Test CreateTenantRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.chats_api import ChatsApi


class TestChatsApi(unittest.TestCase):
    """ChatsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatsApi()

    def tearDown(self) -> None:
        pass

    def test_chat_options(self) -> None:
        """Test case for chat_options

        Chat Options
        """
        pass

    def test_chats_options(self) -> None:
        """Test case for chats_options

        Chats Options
        """
        pass

    def test_create_chat(self) -> None:
        """Test case for create_chat

        Create Chat
        """
        pass

    def test_delete_chat(self) -> None:
        """Test case for delete_chat

        Delete Chat
        """
        pass

    def test_list_chats(self) -> None:
        """Test case for list_chats

        List Chats
        """
        pass

    def test_show_chat(self) -> None:
        """Test case for show_chat

        Show Chat
        """
        pass

    def test_update_chat(self) -> None:
        """Test case for update_chat

        Update Chat
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.roles_api import RolesApi


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RolesApi()

    def tearDown(self) -> None:
        pass

    def test_create_role(self) -> None:
        """Test case for create_role

        Create Role
        """
        pass

    def test_delete_role(self) -> None:
        """Test case for delete_role

        Delete Role
        """
        pass

    def test_list_role_users(self) -> None:
        """Test case for list_role_users

        List Role Users
        """
        pass

    def test_list_role_users_relationship(self) -> None:
        """Test case for list_role_users_relationship

        List Role Users Relationship
        """
        pass

    def test_list_roles(self) -> None:
        """Test case for list_roles

        List Roles
        """
        pass

    def test_role_options(self) -> None:
        """Test case for role_options

        Role Options
        """
        pass

    def test_role_users_options(self) -> None:
        """Test case for role_users_options

        Role Users Options
        """
        pass

    def test_role_users_relationships_options(self) -> None:
        """Test case for role_users_relationships_options

        Role Users Relationships Options
        """
        pass

    def test_roles_options(self) -> None:
        """Test case for roles_options

        Roles Options
        """
        pass

    def test_show_role(self) -> None:
        """Test case for show_role

        Show Role
        """
        pass

    def test_update_role(self) -> None:
        """Test case for update_role

        Update Role
        """
        pass


if __name__ == '__main__':
    unittest.main()
